diff --git a/contrib/ast-db-manage/README.md b/contrib/ast-db-manage/README.md
index 42f2376d356f617bf641755a9b858e6e8937b7e0..f2ba41ed8b250ef98c4317789fcc9ff79163f7f8 100644
--- a/contrib/ast-db-manage/README.md
+++ b/contrib/ast-db-manage/README.md
@@ -12,7 +12,7 @@ repositories include:
  * `cdr` - Table used for Asterisk to store CDR records
  * `config` - Tables used for Asterisk realtime configuration
  * `queue_log` - Table used for Asterisk to store Queue Log records
- * `voicemail` - Tables used for `ODBC_STOARGE` of voicemail messages
+ * `voicemail` - Tables used for `ODBC_STORAGE` of voicemail messages
 
 Alembic uses SQLAlchemy, which has support for
 [many databases](http://docs.sqlalchemy.org/en/rel_0_8/dialects/index.html).
diff --git a/contrib/ast-db-manage/config/versions/1ae0609b6646_increse_reg_server_size.py b/contrib/ast-db-manage/config/versions/1ae0609b6646_increse_reg_server_size.py
index afd234b576995992edb772c5cfc546d5a34179fc..0646e24230df9035fc15d92c9d9ee2065e70e113 100644
--- a/contrib/ast-db-manage/config/versions/1ae0609b6646_increse_reg_server_size.py
+++ b/contrib/ast-db-manage/config/versions/1ae0609b6646_increse_reg_server_size.py
@@ -1,4 +1,4 @@
-"""increse reg server size
+"""increase reg server size
 
 Revision ID: 1ae0609b6646
 Revises: 61797b9fced6
diff --git a/contrib/ast-db-manage/config/versions/4da0c5f79a9c_create_tables.py b/contrib/ast-db-manage/config/versions/4da0c5f79a9c_create_tables.py
index 01c40acbc105e1b988a5e9523ede1b9fb248e00d..1c558a0d6c613cf68d4aaa0b7ea038602c023f8c 100644
--- a/contrib/ast-db-manage/config/versions/4da0c5f79a9c_create_tables.py
+++ b/contrib/ast-db-manage/config/versions/4da0c5f79a9c_create_tables.py
@@ -3,7 +3,7 @@
 #
 # Copyright (C) 2013, Russell Bryant
 #
-# Russell Bryant <russell@rusellbryant.net>
+# Russell Bryant <russell@russellbryant.net>
 #
 # See http://www.asterisk.org for more information about
 # the Asterisk project. Please do not directly contact
diff --git a/contrib/ast-db-manage/voicemail/versions/a2e9769475e_create_tables.py b/contrib/ast-db-manage/voicemail/versions/a2e9769475e_create_tables.py
index 3dc4d47c4a899447774c6ac760a9491ef7c8fed0..3dc1c811dd35908291b6faaff7753751e25756a4 100644
--- a/contrib/ast-db-manage/voicemail/versions/a2e9769475e_create_tables.py
+++ b/contrib/ast-db-manage/voicemail/versions/a2e9769475e_create_tables.py
@@ -3,7 +3,7 @@
 #
 # Copyright (C) 2013, Russell Bryant
 #
-# Russell Bryant <russell@rusellbryant.net>
+# Russell Bryant <russell@russellbryant.net>
 #
 # See http://www.asterisk.org for more information about
 # the Asterisk project. Please do not directly contact
diff --git a/contrib/init.d/rc.debian.asterisk b/contrib/init.d/rc.debian.asterisk
index c58ab23be8605a2996a066f23463359dfaa78f23..e2188b0902a7d35ff175fd5483fe3c31ae05022a 100755
--- a/contrib/init.d/rc.debian.asterisk
+++ b/contrib/init.d/rc.debian.asterisk
@@ -3,7 +3,7 @@
 #
 # Mon Jun 04 2007 Iñaki Baz Castillo <ibc@in.ilimit.es>
 # - Eliminated SAFE_ASTERISK since it doesn't work as LSB script (it could require a independent "safe_asterisk" init script).
-# - Load and use the standar "/lib/lsb/init-functions".
+# - Load and use the standard "/lib/lsb/init-functions".
 # - Added "--oknodo" to "start-stop-daemon" for compatibility with LSB:
 #   http://www.linux-foundation.org/spec/refspecs/LSB_3.0.0/LSB-Core-generic/LSB-Core-generic/iniscrptact.html
 #
diff --git a/contrib/scripts/ast_coredumper b/contrib/scripts/ast_coredumper
index 28683129cd7d44e1866cf137f67fb07b4b3e54df..353137f670aedbc2cf5e743a5fffa0e0d54de16d 100755
--- a/contrib/scripts/ast_coredumper
+++ b/contrib/scripts/ast_coredumper
@@ -600,7 +600,7 @@ FILES
 
 #@@@HELPEND@@@
 
-# Be careful editng the inline scripts.
+# Be careful editing the inline scripts.
 # They're space-indented.
 
 # We need the python bit because lock_infos isn't
diff --git a/contrib/scripts/ast_loggrabber b/contrib/scripts/ast_loggrabber
index 2036d54baf6470957596d359462aeb430afdf445..b549ec329aa6bb13e4fbd780326dae846e6c0585 100755
--- a/contrib/scripts/ast_loggrabber
+++ b/contrib/scripts/ast_loggrabber
@@ -209,7 +209,7 @@ tar -czvf /tmp/$tardir.tar.gz -C $tmpdir $tardir 2>/dev/null
 
 exit
 
-# Be careful editng the inline scripts.
+# Be careful editing the inline scripts.
 # They're space-indented.
 
 # We need the python bit because lock_infos isn't
@@ -231,7 +231,7 @@ parser.add_argument('--timezone', action='store', required=False)
 args=parser.parse_args()
 
 # We only convert timestamps that are at the beginning of a line
-# or are preceeded by a whilespace character or a '['
+# or are preceeded by a whitespace character or a '['
 rets = re.compile(r'(^|(?<=\s|\[))\d+(\.\d+)?', flags=re.M)
 if args.timezone and len(args.timezone) > 0:
    tzf = tz.tzfile('/usr/share/zoneinfo/' + args.timezone)
diff --git a/contrib/scripts/asterisk.ldap-schema b/contrib/scripts/asterisk.ldap-schema
index 85f9103e297fb2516a5e5a833f3488bcd163caf2..340f06fce998bd1efe31acc5682bffa1a35754ee 100644
--- a/contrib/scripts/asterisk.ldap-schema
+++ b/contrib/scripts/asterisk.ldap-schema
@@ -600,7 +600,7 @@ attributetype ( AstAccountTransport
 
 attributetype ( AstAccountPromiscRedir
         NAME 'AstAccountPromiscRedir'
-        DESC 'Asterisk account promiscous redirects'
+        DESC 'Asterisk account promiscuous redirects'
         EQUALITY caseIgnoreMatch
         SUBSTR caseIgnoreSubstringsMatch
         SYNTAX 1.3.6.1.4.1.1466.115.121.1.15)
diff --git a/contrib/scripts/asterisk.ldif b/contrib/scripts/asterisk.ldif
index 562105730a506514d3e58c64443f1b97d35dd9b1..ab9bd92a38ace2f6f0f27fa2ebfb5bb62b392fbc 100644
--- a/contrib/scripts/asterisk.ldif
+++ b/contrib/scripts/asterisk.ldif
@@ -597,7 +597,7 @@ olcAttributeTypes: ( AstAccountTransport
 #
 olcAttributeTypes: ( AstAccountPromiscRedir
         NAME 'AstAccountPromiscRedir'
-        DESC 'Asterisk account promiscous redirects'
+        DESC 'Asterisk account promiscuous redirects'
         EQUALITY caseIgnoreMatch
         SUBSTR caseIgnoreSubstringsMatch
         SYNTAX 1.3.6.1.4.1.1466.115.121.1.15)
diff --git a/contrib/scripts/loadtest.tcl b/contrib/scripts/loadtest.tcl
index d216f489b720c072d033262d4ae53a285edccca4..1bdcc28c053d1b7065cbff568a6866e40927bac1 100644
--- a/contrib/scripts/loadtest.tcl
+++ b/contrib/scripts/loadtest.tcl
@@ -14,7 +14,7 @@
 
 # where Asterisk's pbx/pbx_spool.c will be looking for work
 set SPOOLDIR /var/spool/asterisk/outgoing
-# pbx_spool is fairly aggresive, so make files here first
+# pbx_spool is fairly aggressive, so make files here first
 set TEMPDIR /tmp
 
 if { ![file writable $SPOOLDIR] } {
diff --git a/contrib/scripts/retrieve_extensions_from_sql.pl b/contrib/scripts/retrieve_extensions_from_sql.pl
index 47210ebf3ee3f8d0140654eefd50c0cb548b5c70..13a284d1839c77d1edff1d4535023c0a74658f01 100644
--- a/contrib/scripts/retrieve_extensions_from_sql.pl
+++ b/contrib/scripts/retrieve_extensions_from_sql.pl
@@ -4,7 +4,7 @@
 # Copy Policy:  GNU Public Licence Version 2 or later
 # URL:          http://www.peternixon.net/code/
 # Supported:    PostgreSQL, Oracle, MySQL
-# Copyright:    2004 Peter Nixon <codemonkey@petenixon.net>
+# Copyright:    2004 Peter Nixon <codemonkey@peternixon.net>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
diff --git a/contrib/scripts/safe_asterisk.8 b/contrib/scripts/safe_asterisk.8
index 19e1728a66cd0695bcd99b7d3ce59f84c578bf05..dde91738171bb6d92208e37ebd15780ce746152d 100644
--- a/contrib/scripts/safe_asterisk.8
+++ b/contrib/scripts/safe_asterisk.8
@@ -26,7 +26,7 @@ remote shell session) you can use:
   screendump 9
 
 The init script of the Debian package should be able to run safe_asterisk
-as the asterisk service, if so configured. See coments in
+as the asterisk service, if so configured. See comments in
 /etc/default/asterisk
 
 .SH FILES
diff --git a/contrib/scripts/valgrind_compare b/contrib/scripts/valgrind_compare
index 9f814d4548fcf6d8ae85eb2c9efda822715c9108..a8bffaf4e4780c83cbb70c9f870041fdd3f41af2 100755
--- a/contrib/scripts/valgrind_compare
+++ b/contrib/scripts/valgrind_compare
@@ -1,6 +1,6 @@
 #!/bin/bash
 
-# compare_valgrind: diff two valgrinf memory usage logs. Masks out PIDs,
+# compare_valgrind: diff two valgrind memory usage logs. Masks out PIDs,
 # addresses and such that should normally be different.
 #
 # Usage: ./compare_valgrind file1.log file2.log | less
diff --git a/contrib/scripts/voicemailpwcheck.py b/contrib/scripts/voicemailpwcheck.py
index 452255c35b1ae7e86f7334656295dc8fe04d14c4..7636df31279b0914732faa594952679ee62e6a54 100755
--- a/contrib/scripts/voicemailpwcheck.py
+++ b/contrib/scripts/voicemailpwcheck.py
@@ -22,7 +22,7 @@ REQUIRED_LENGTH = 6
 # Regular expressions that match against invalid passwords
 REGEX_BLACKLIST = [
     ("(?P<digit>\d)(?P=digit){%d}" % (REQUIRED_LENGTH - 1),
-        "%d consective numbers that are the same" % REQUIRED_LENGTH)
+        "%d consecutive numbers that are the same" % REQUIRED_LENGTH)
 ]
 
 
diff --git a/contrib/utils/zones2indications.c b/contrib/utils/zones2indications.c
index d1def5300022a65728072f4b8aff54098293bf13..cfe85eb463a616948b9fc5ab7a7aa77a5c41c9d0 100644
--- a/contrib/utils/zones2indications.c
+++ b/contrib/utils/zones2indications.c
@@ -17,7 +17,7 @@
  */
 
 /*! \file
  * \brief print libtonozone data as Asterisk indications.conf
  */
 
 #include <stdio.h>
@@ -107,7 +107,7 @@ int print_all() {
 
 void usage() {
   fprintf(stderr,
-      PROGRAM ": print libtonozone data as Asterisk indications.conf\n"
+      PROGRAM ": print libtonezone data as Asterisk indications.conf\n"
       "\n"
       "Usage:\n"
       "  " PROGRAM " -a         Print all countries\n"
@@ -17,7 +17,7 @@
 
 /*! \file
- * \brief print libtonozone data as Asterisk indications.conf
+ * \brief print libtonezone data as Asterisk indications.conf
  */
 